@@ -9,8 +9,10 @@ if __name__ == "__main__":
 from q2db.cursor import Q2Cursor
 from q2gui.q2model import Q2CursorModel
 from q2rad import Q2Form
+from q2gui.q2app import Q2Actions
 from q2gui import q2app
 import gettext
+import base64
 
 _ = gettext.gettext
 
@@ -22,8 +24,12 @@ class Q2Constants(Q2Form):
 
     def on_init(self):
         self.add_control("const_name", _("Name"), datatype="char", datalen=100, pk="*")
+        loader_actions = Q2Actions()
+        loader_actions.show_main_button = False
+        loader_actions.add_action("Load image", self.load_image)
+        loader_actions.add_action("Show as image", self.show_image)
         self.add_control("const_text", _("Label"), datatype="char", datalen=250)
-        self.add_control("const_value", _("Value"), datatype="text")
+        self.add_control("const_value", _("Value"), datatype="text", actions=loader_actions)
         self.add_control("comment", _("Comment"), datatype="text")
 
         cursor: Q2Cursor = self.q2_app.db_data.table(table_name="constants")
@@ -32,6 +38,16 @@ class Q2Constants(Q2Form):
         self.set_model(model)
         self.add_action("/crud")
 
+    def load_image(self):
+        _q2app: q2app = self.q2_app
+        image_file = _q2app.get_open_file_dialoq("Open image", filter="Images (*.png *.jpg)")[0]
+        self.s.const_value = base64.b64encode(open(image_file, "rb").read()).decode()
+
+    def show_image(self):
+        iform = Q2Form("Image viewer")
+        iform.add_control("image", control="image", data=self.s.const_value)
+        iform.run()
+
 
 class q2const:
     def __getattr__(self, __name):
