@@ -7,7 +7,7 @@ if __name__ == "__main__":
 
 
 from q2rad import Q2App, Q2Form
-from q2gui.q2dialogs import q2Mess, q2AskYN, Q2WaitShow
+from q2gui.q2dialogs import q2Mess, q2AskYN, Q2WaitShow, q2Wait
 from q2gui.q2model import Q2CursorModel
 from q2db.schema import Q2DbSchema
 from q2db.db import Q2Db
@@ -36,6 +36,7 @@ import gettext
 
 # import urllib.request
 import os
+import pip
 import json
 import subprocess
 import shutil
@@ -43,6 +44,8 @@ import pkgutil
 
 
 # TODO: excel custom format 2 report
+# TODO: child grid first show - splitter size
+# TODO: qrid - hightlight current column
 
 
 q2_modules = ("q2rad", "q2gui", "q2db", "q2report")
@@ -439,30 +442,36 @@ class Q2RadApp(Q2App):
         pass
 
     def pip_install(self, package, latest_version):
-        return subprocess.check_call(
-            [
-                sys.executable.replace("w.exe", ".exe"),
-                "-m",
-                "pip",
-                "install",
-                "--upgrade",
-                "--no-cache-dir",
-                f"{package}=={latest_version}",
-            ],
-            shell=True if "win" in sys.platform else False,
+        q2Wait(
+            lambda: subprocess.check_call(
+                [
+                    sys.executable.replace("w.exe", ".exe"),
+                    "-m",
+                    "pip",
+                    "install",
+                    "--upgrade",
+                    "--no-cache-dir",
+                    f"{package}=={latest_version}",
+                ],
+                shell=True if "win" in sys.platform else False,
+            ),
+            _("Installing package %s...") % package,
         )
 
     def pip_uninstall(self, package):
-        return subprocess.check_call(
-            [
-                sys.executable.replace("w.exe", ".exe"),
-                "-m",
-                "pip",
-                "uninstall",
-                "-y",
-                f"{package}",
-            ],
-            shell=True if "win" in sys.platform else False,
+        q2Wait(
+            lambda: subprocess.check_call(
+                [
+                    sys.executable.replace("w.exe", ".exe"),
+                    "-m",
+                    "pip",
+                    "uninstall",
+                    "-y",
+                    f"{package}",
+                ],
+                shell=True if "win" in sys.platform else False,
+            ),
+            _("Uninstalling package %s...") % package,
         )
 
     def check_app_update(self):
@@ -590,26 +599,28 @@ class Q2RadApp(Q2App):
         sql = f"""
             select
                 column
-                ,label
-                ,gridlabel
-                ,nogrid
-                ,noform
-                ,`check`
-                ,control
-                ,pic
-                ,datatype
-                ,datalen
-                ,datadec
-                ,migrate
-                ,pk
-                ,ai
-                ,to_table
-                ,to_column
-                ,related
-                ,to_form
-                ,code_valid as valid
-                /*,code_when as when
-                ,code_show as show*/
+                , label
+                , gridlabel
+                , nogrid
+                , noform
+                , `check`
+                , control
+                , pic
+                , datatype
+                , datalen
+                , datadec
+                , migrate
+                , disabled
+                , readonly
+                , pk
+                , ai
+                , to_table
+                , to_column
+                , related
+                , to_form
+                , code_valid as valid
+                , code_when as _when
+                , code_show as _show
             from lines
             where name = '{name}'
             order by seq
@@ -643,8 +654,9 @@ class Q2RadApp(Q2App):
             if x.get("to_form"):
                 x["to_form"] = self.get_form(x["to_form"])
             x["valid"] = self.code_runner(x["valid"], form)
-            # x["show"] = self.code_runner(x["show"], form)
-            # x["when"] = self.code_runner(x["when"], form)
+            if x.get("_show"):
+                x["show"] = self.code_runner(x["_show"], form)
+            x["when"] = self.code_runner(x["_when"], form)
             form.add_control(**x)
 
         # add actions
@@ -738,9 +750,8 @@ class Q2RadApp(Q2App):
         _form = form
         # to provide return ability for exec
 
-        def real_runner():
+        def real_runner(**args):
             # make exec stop on return
-
             class ReturnEvent(Exception):
                 pass
 
@@ -754,6 +765,9 @@ class Q2RadApp(Q2App):
                 "myapp": self,
                 "__name__": __name__,
             }
+            for x in args:
+                __locals_dict[x] = args[x]
+
             code = self.code_compiler(script)
             # print("code compiled", "\n" ,script)
             if code["code"]:
